@@ -24,18 +24,17 @@ class TPADownloadCommand(Command):
         Execute the command to download a file(s) to the TPA.
         """
 
-        tpa_client = get_tpa_default_client(
+        async with get_tpa_default_client(
             self.cli_args.tpa_base_url,
-        )
+        ) as client:
+            sboms = client.list_sboms(query=self.cli_args.query, sort="ingested")
 
-        sboms = tpa_client.list_sboms(query=self.cli_args.query, sort="ingested")
+            async for sbom in sboms:
+                # normalize the name to be a valid filename
+                name = utils.normalize_file_name(sbom.name)
+                local_path = self.cli_args.output / f"{name}.json"
 
-        async for sbom in sboms:
-            # normalize the name to be a valid filename
-            name = utils.normalize_file_name(sbom.name)
-            local_path = self.cli_args.output / f"{name}.json"
-
-            await tpa_client.download_sbom(sbom.id, local_path)
+                await client.download_sbom(sbom.id, local_path)
         self.exit_code = 0
 
     async def save(self) -> None:
